@@ -28,6 +28,9 @@
 #include <gio/gio.h>
 #include <gio/gdesktopappinfo.h>
 
+#define GNOME_DESKTOP_USE_UNSTABLE_API
+#include <libgnome-desktop/gnome-systemd.h>
+
 #ifdef HAVE_SYSTEMD
 #ifdef ENABLE_SYSTEMD_JOURNAL
 #include <systemd/sd-journal.h>
@@ -960,6 +963,13 @@ app_launched (GAppLaunchContext *ctx,
         g_variant_lookup (platform_data, "startup-notification-id", "s", &sn_id);
         app->priv->pid = pid;
         app->priv->startup_id = sn_id;
+
+        /* We are not interested in the result. */
+        gnome_start_systemd_scope (app->priv->desktop_id,
+                                   pid,
+                                   NULL,
+                                   NULL,
+                                   NULL, NULL, NULL);
 }
 
 #ifdef ENABLE_SYSTEMD_JOURNAL
